@@ -1,9 +1,9 @@
 {-
-Copyright (C) 2009 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2009-2011 John Goerzen <jgoerzen@complete.org>
 
 All rights reserved.
 
-For license and copyright information, see the file COPYRIGHT
+For license and copyright information, see the file LICENSE
 -}
 
 module TestMap where
@@ -12,12 +12,13 @@ import Data.Convertible
 import Test.QuickCheck
 import Test.QuickCheck.Tools
 import Test.QuickCheck.Instances
+import qualified Test.QuickCheck.Property as P
 import qualified Data.Map as Map
 
-propListMap :: [(Int, Int)] -> Result
+propListMap :: [(Int, Int)] -> P.Result
 propListMap x = safeConvert x @?= Right (Map.fromList x)
 
-propMapList :: Map.Map Int Int -> Result
+propMapList :: Map.Map Int Int -> P.Result
 propMapList x = safeConvert x @?= Right (Map.toList x)
 
 allt = [q "[(Int, Int)] -> Map" propListMap,
